@@ -13,10 +13,11 @@
 #    under the License.
 #
 
-from neutron.db import api as db_api
-from neutron.db import common_db_mixin
 from neutron_lib import context as n_context
+from neutron_lib.db import api as db_api
 from neutron_lib.db import model_base
+from neutron_lib.db import model_query
+from neutron_lib.db import utils as db_utils
 from neutron_lib import exceptions as n_exc
 
 import sqlalchemy as sa
@@ -24,9 +25,6 @@ from sqlalchemy import orm
 from sqlalchemy.orm import exc
 from sqlalchemy import sql
 
-import six
-
-from oslo_log import helpers as log_helpers
 from oslo_utils import uuidutils
 
 from networking_sfc._i18n import _
@@ -64,57 +62,6 @@ def singleton(class_):
     return getinstance
 
 
-@singleton
-class IDAllocation(object):
-    def __init__(self, context):
-        # Get the initial range from conf file.
-        conf_obj = {'group': [1, 255], 'portchain': [256, 65536]}
-        self.conf_obj = conf_obj
-        self.context = context
-
-    @log_helpers.log_method_call
-    def assign_intid(self, type_, uuid):
-        query = self.context.session.query(UuidIntidAssoc).filter_by(
-            type_=type_).order_by(UuidIntidAssoc.intid)
-
-        allocated_int_ids = {obj.intid for obj in query.all()}
-
-        # Find the first one from the available range that
-        # is not in allocated_int_ids
-        start, end = self.conf_obj[type_][0], self.conf_obj[type_][1] + 1
-        for init_id in six.moves.range(start, end):
-            if init_id not in allocated_int_ids:
-                with db_api.context_manager.writer.using(self.context):
-                    uuid_intid = UuidIntidAssoc(
-                        uuid, init_id, type_)
-                    self.context.session.add(uuid_intid)
-                return init_id
-        return None
-
-    @log_helpers.log_method_call
-    def get_intid_by_uuid(self, type_, uuid):
-
-        query_obj = self.context.session.query(UuidIntidAssoc).filter_by(
-            type_=type_, uuid=uuid).first()
-        if query_obj:
-            return query_obj.intid
-        return None
-
-    @log_helpers.log_method_call
-    def release_intid(self, type_, intid):
-        """Release int id.
-
-        @param: type_: str
-        @param: intid: int
-        """
-        with db_api.context_manager.writer.using(self.context):
-            query_obj = self.context.session.query(UuidIntidAssoc).filter_by(
-                intid=intid, type_=type_).first()
-
-            if query_obj:
-                self.session.delete(query_obj)
-
-
 class PathPortAssoc(model_base.BASEV2):
     """path port association table.
 
@@ -177,7 +124,7 @@ class PathNode(model_base.BASEV2, model_base.HasId, model_base.HasProject):
         sa.ForeignKey('sfc_path_nodes.id', ondelete='SET NULL'))
 
 
-class OVSSfcDriverDB(common_db_mixin.CommonDbMixin):
+class OVSSfcDriverDB(object):
     def initialize(self):
         self.admin_context = n_context.get_admin_context()
 
@@ -200,7 +147,7 @@ class OVSSfcDriverDB(common_db_mixin.CommonDbMixin):
                'previous_node_id': node['previous_node_id']
                }
 
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _make_port_detail_dict(self, port, fields=None):
         res = {'id': port['id'],
@@ -219,7 +166,7 @@ class OVSSfcDriverDB(common_db_mixin.CommonDbMixin):
                'correlation': port['correlation']
                }
 
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _make_pathport_assoc_dict(self, assoc, fields=None):
         res = {'pathnode_id': assoc['pathnode_id'],
@@ -227,53 +174,54 @@ class OVSSfcDriverDB(common_db_mixin.CommonDbMixin):
                'weight': assoc['weight'],
                }
 
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _get_path_node(self, id):
         try:
-            node = self._get_by_id(self.admin_context, PathNode, id)
+            node = model_query.get_by_id(self.admin_context, PathNode, id)
         except exc.NoResultFound:
             raise NodeNotFound(node_id=id)
         return node
 
     def _get_port_pair_detail(self, id):
         try:
-            port = self._get_by_id(self.admin_context, PortPairDetail, id)
+            port = model_query.get_by_id(
+                self.admin_context, PortPairDetail, id)
         except exc.NoResultFound:
             raise PortPairDetailNotFound(port_id=id)
         return port
 
     def create_port_pair_detail(self, port):
-        with db_api.context_manager.writer.using(self.admin_context):
-            args = self._filter_non_model_columns(port, PortPairDetail)
+        with db_api.CONTEXT_WRITER.using(self.admin_context):
+            args = db_utils.filter_non_model_columns(port, PortPairDetail)
             args['id'] = uuidutils.generate_uuid()
             port_obj = PortPairDetail(**args)
             self.admin_context.session.add(port_obj)
             return self._make_port_detail_dict(port_obj)
 
     def create_path_node(self, node):
-        with db_api.context_manager.writer.using(self.admin_context):
-            args = self._filter_non_model_columns(node, PathNode)
+        with db_api.CONTEXT_WRITER.using(self.admin_context):
+            args = db_utils.filter_non_model_columns(node, PathNode)
             args['id'] = uuidutils.generate_uuid()
             node_obj = PathNode(**args)
             self.admin_context.session.add(node_obj)
             return self._make_pathnode_dict(node_obj)
 
     def create_pathport_assoc(self, assoc):
-        with db_api.context_manager.writer.using(self.admin_context):
-            args = self._filter_non_model_columns(assoc, PathPortAssoc)
+        with db_api.CONTEXT_WRITER.using(self.admin_context):
+            args = db_utils.filter_non_model_columns(assoc, PathPortAssoc)
             assoc_obj = PathPortAssoc(**args)
             self.admin_context.session.add(assoc_obj)
             return self._make_pathport_assoc_dict(assoc_obj)
 
     def delete_pathport_assoc(self, pathnode_id, portdetail_id):
-        with db_api.context_manager.writer.using(self.admin_context):
+        with db_api.CONTEXT_WRITER.using(self.admin_context):
             self.admin_context.session.query(PathPortAssoc).filter_by(
                 pathnode_id=pathnode_id,
                 portpair_id=portdetail_id).delete()
 
     def update_port_detail(self, id, port):
-        with db_api.context_manager.writer.using(self.admin_context):
+        with db_api.CONTEXT_WRITER.using(self.admin_context):
             port_obj = self._get_port_detail(id)
             for key, value in port.items():
                 if key == 'path_nodes':
@@ -281,7 +229,7 @@ class OVSSfcDriverDB(common_db_mixin.CommonDbMixin):
                     for pn in value:
                         pn_id = pn['pathnode_id']
                         self._get_path_node(pn_id)
-                        query = self._model_query(
+                        query = model_query.query_with_hooks(
                             self.admin_context, PathPortAssoc)
                         pn_association = query.filter_by(
                             pathnode_id=pn_id,
@@ -301,13 +249,13 @@ class OVSSfcDriverDB(common_db_mixin.CommonDbMixin):
             return self._make_port_detail_dict(port_obj)
 
     def update_path_node(self, id, node):
-        with db_api.context_manager.writer.using(self.admin_context):
+        with db_api.CONTEXT_WRITER.using(self.admin_context):
             node_obj = self._get_path_node(id)
             for key, value in node.items():
                 if key == 'portpair_details':
                     pds = []
                     for pd_id in value:
-                        query = self._model_query(
+                        query = model_query.query_with_hooks(
                             self.admin_context, PathPortAssoc)
                         pd_association = query.filter_by(
                             pathnode_id=id,
@@ -326,36 +274,36 @@ class OVSSfcDriverDB(common_db_mixin.CommonDbMixin):
             return self._make_pathnode_dict(node_obj)
 
     def delete_port_pair_detail(self, id):
-        with db_api.context_manager.writer.using(self.admin_context):
+        with db_api.CONTEXT_WRITER.using(self.admin_context):
             port_obj = self._get_port_pair_detail(id)
             self.admin_context.session.delete(port_obj)
 
     def delete_path_node(self, id):
-        with db_api.context_manager.writer.using(self.admin_context):
+        with db_api.CONTEXT_WRITER.using(self.admin_context):
             node_obj = self._get_path_node(id)
             self.admin_context.session.delete(node_obj)
 
     def get_port_detail(self, id):
-        with db_api.context_manager.reader.using(self.admin_context):
+        with db_api.CONTEXT_READER.using(self.admin_context):
             port_obj = self._get_port_pair_detail(id)
             return self._make_port_detail_dict(port_obj)
 
     def get_port_detail_without_exception(self, id):
-        with db_api.context_manager.reader.using(self.admin_context):
+        with db_api.CONTEXT_READER.using(self.admin_context):
             try:
-                port = self._get_by_id(
+                port = model_query.get_by_id(
                     self.admin_context, PortPairDetail, id)
             except exc.NoResultFound:
                 return None
             return self._make_port_detail_dict(port)
 
     def get_path_node(self, id):
-        with db_api.context_manager.reader.using(self.admin_context):
+        with db_api.CONTEXT_READER.using(self.admin_context):
             node_obj = self._get_path_node(id)
         return self._make_pathnode_dict(node_obj)
 
     def get_path_nodes_by_filter(self, filters=None):
-        with db_api.context_manager.reader.using(self.admin_context):
+        with db_api.CONTEXT_READER.using(self.admin_context):
             qry = self._get_path_nodes_by_filter(filters)
             all_items = qry.all()
             if all_items:
@@ -363,7 +311,7 @@ class OVSSfcDriverDB(common_db_mixin.CommonDbMixin):
         return None
 
     def get_path_node_by_filter(self, filters=None):
-        with db_api.context_manager.reader.using(self.admin_context):
+        with db_api.CONTEXT_READER.using(self.admin_context):
             qry = self._get_path_nodes_by_filter(filters)
             first = qry.first()
             if first:
@@ -383,7 +331,7 @@ class OVSSfcDriverDB(common_db_mixin.CommonDbMixin):
         return qry
 
     def get_port_details_by_filter(self, filters=None):
-        with db_api.context_manager.reader.using(self.admin_context):
+        with db_api.CONTEXT_READER.using(self.admin_context):
             qry = self._get_port_details_by_filter(filters)
             all_items = qry.all()
             if all_items:
@@ -392,7 +340,7 @@ class OVSSfcDriverDB(common_db_mixin.CommonDbMixin):
         return None
 
     def get_port_detail_by_filter(self, filters=None):
-        with db_api.context_manager.reader.using(self.admin_context):
+        with db_api.CONTEXT_READER.using(self.admin_context):
             qry = self._get_port_details_by_filter(filters)
             first = qry.first()
             if first:
