@@ -15,25 +15,25 @@
 #
 
 import sys
-import uuid
-
-import mock
+from unittest import mock
 
 from neutronclient import shell
 from neutronclient.tests.unit import test_cli20
 
 from networking_sfc.cli import port_pair_group as pg
 
-pp1 = str(uuid.uuid4())
-pp2 = str(uuid.uuid4())
-pp3 = str(uuid.uuid4())
-pp4 = str(uuid.uuid4())
+from oslo_utils import uuidutils
+
+pp1 = uuidutils.generate_uuid()
+pp2 = uuidutils.generate_uuid()
+pp3 = uuidutils.generate_uuid()
+pp4 = uuidutils.generate_uuid()
 
 
 class CLITestV20PortGroupExtensionJSON(test_cli20.CLITestV20Base):
     def setUp(self):
-        self._mock_extension_loading()
         super(CLITestV20PortGroupExtensionJSON, self).setUp()
+        self._mock_extension_loading()
         self.register_non_admin_status_resource('port_pair_group')
 
     def _create_patch(self, name, func=None):
@@ -50,13 +50,15 @@ class CLITestV20PortGroupExtensionJSON(test_cli20.CLITestV20Base):
         return port_pair_group
 
     def test_ext_cmd_loaded(self):
-        shell.NeutronShell('2.0')
+        neutron_shell = shell.NeutronShell('2.0')
         ext_cmd = {'port-pair-group-list': pg.PortPairGroupList,
                    'port-pair-group-create': pg.PortPairGroupCreate,
                    'port-pair-group-update': pg.PortPairGroupUpdate,
                    'port-pair-group-delete': pg.PortPairGroupDelete,
                    'port-pair-group-show': pg.PortPairGroupShow}
-        self.assertDictContainsSubset(ext_cmd, shell.COMMANDS['2.0'])
+        for cmd_name, cmd_class in ext_cmd.items():
+            found = neutron_shell.command_manager.find_command([cmd_name])
+            self.assertEqual(cmd_class, found[0])
 
     def test_create_port_pair_group_with_mandatory_args(self):
         """Create port_pair_group: myname."""
@@ -70,7 +72,7 @@ class CLITestV20PortGroupExtensionJSON(test_cli20.CLITestV20Base):
         self._test_create_resource(resource, cmd, name, myid, args,
                                    position_names, position_values)
 
-    def test_create_port_pair_group_with_ingress_egress_port_group(self):
+    def test_create_port_pair_group_with_multi_port_pairs(self):
         """Create port_pair_group: myname with multiple port pairs"""
         resource = 'port_pair_group'
         cmd = pg.PortPairGroupCreate(test_cli20.MyApp(sys.stdout), None)
@@ -82,6 +84,44 @@ class CLITestV20PortGroupExtensionJSON(test_cli20.CLITestV20Base):
         self._test_create_resource(resource, cmd, name, myid, args,
                                    position_names, position_values)
 
+    def test_create_port_pair_group_with_lb_fields_param(self):
+        """Create port_pair_group: myname with lb_fields parameter"""
+        resource = 'port_pair_group'
+        cmd = pg.PortPairGroupCreate(test_cli20.MyApp(sys.stdout),
+                                     None)
+        name = 'myname'
+        myid = 'myid'
+        ppg_param = 'lb_fields=ip_src&ip_dst'
+        ppg_exp = {"lb_fields": ["ip_src", "ip_dst"]}
+        args = [name, '--port-pair', pp1,
+                '--port-pair-group-parameters', ppg_param]
+        position_names = ['name', 'port_pairs',
+                          'port_pair_group_parameters']
+        position_values = [name, [pp1], ppg_exp]
+        self._test_create_resource(resource, cmd, name, myid, args,
+                                   position_names, position_values)
+
+    def test_create_port_pair_group_with_ppg_n_tuple_mapping_param(self):
+        """Create port_pair_group: myname with ppg_n_tuple_mapping parameter"""
+        resource = 'port_pair_group'
+        cmd = pg.PortPairGroupCreate(test_cli20.MyApp(sys.stdout),
+                                     None)
+        name = 'myname'
+        myid = 'myid'
+        ppg_param = ('ppg_n_tuple_mapping=source_ip_prefix_ingress=None'
+                     '&source_ip_prefix_egress=None')
+        ppg_exp = {
+            'ppg_n_tuple_mapping': {
+                'ingress_n_tuple': {'source_ip_prefix': 'None'},
+                'egress_n_tuple': {'source_ip_prefix': 'None'}}}
+        args = [name, '--port-pair', pp1,
+                '--port-pair-group-parameters', ppg_param]
+        position_names = ['name', 'port_pairs',
+                          'port_pair_group_parameters']
+        position_values = [name, [pp1], ppg_exp]
+        self._test_create_resource(resource, cmd, name, myid, args,
+                                   position_names, position_values)
+
     def test_delete_port_pair_group(self):
         """Delete port_pair_group: myid."""
         resource = 'port_pair_group'
@@ -105,8 +145,7 @@ class CLITestV20PortGroupExtensionJSON(test_cli20.CLITestV20Base):
         resource = 'port_pair_group'
         cmd = pg.PortPairGroupUpdate(test_cli20.MyApp(sys.stdout), None)
         myid = 'myid'
-        args = [myid, '--port-pair', pp1,
-                '--port-pair', pp2, '--description', 'my_port_group',
+        args = [myid, '--port-pair', pp1, '--port-pair', pp2,
                 '--description', 'my_port_pair_group']
         updatefields = {'port_pairs': [pp1, pp2],
                         'description': 'my_port_pair_group'}
